@@ -16,7 +16,7 @@ def test_img_b64_to_arr():
 
 
 def test_img_arr_to_b64():
-    img_file = osp.join(data_dir, 'apc2016_obj3.jpg')
+    img_file = osp.join(data_dir, "annotated_with_data/apc2016_obj3.jpg")
     img_arr = np.asarray(PIL.Image.open(img_file))
     img_b64 = image_module.img_arr_to_b64(img_arr)
     img_arr2 = image_module.img_b64_to_arr(img_b64)
@@ -24,8 +24,8 @@ def test_img_arr_to_b64():
 
 
 def test_img_data_to_png_data():
-    img_file = osp.join(data_dir, 'apc2016_obj3.jpg')
-    with open(img_file, 'rb') as f:
+    img_file = osp.join(data_dir, "annotated_with_data/apc2016_obj3.jpg")
+    with open(img_file, "rb") as f:
         img_data = f.read()
     png_data = image_module.img_data_to_png_data(img_data)
     assert isinstance(png_data, bytes)
